<?php

/**
 * @file
 * Admin settings for Total Subscription module.
 */

/**
 * Callback function for Admin settings for Mails.
 */
function total_subscription_mail_admin_form_settings() {
  $form = array();
  $form['total_subscription_email_address'] = array(
    '#type' => 'textfield',
    '#default_value' => variable_get('total_subscription_email_address', ''),
    '#description' => t('Please specify the email address'),
    '#title' => t('Email address'),
  );
  $form['total_subscription_subject_published'] = array(
    '#type' => 'textfield',
    '#default_value' => variable_get('total_subscription_subject_published', ''),
    '#description' => t('Please specify the subject when some content will published.'),
    '#title' => t('Subject when content is published.'),
  );
  $form['total_subscription_subject_subscription'] = array(
    '#type' => 'textfield',
    '#default_value' => variable_get('total_subscription_subject_subscription', ''),
    '#description' => t('Please specify the subject when someone subscribes.'),
    '#title' => t('Subscription subject'),
  );
  $form['total_subscription_node_update'] = array(
    '#type' => 'checkbox',
    '#default_value' => variable_get('total_subscription_node_update', 0),
    '#description' => t('Whether to receive an email if the node has changed
    (if the checkbox is disabled, only new and switched to published nodes will be emailed).'),
    '#title' => t('Subscribe for updates'),
  );
  $total_subscription_shorten_url = t('Please check this if you want to shorten subscribe/unsubscribe urls.') .
    ' ' . l(t('Shorten URLs'), 'http://drupal.org/project/shorten') . ' ' . t('module required.');
  $form['total_subscription_shorten_url'] = array(
    '#type' => 'checkbox',
    '#default_value' => variable_get('total_subscription_shorten_url', 0),
    '#title' => t('Shorten the URLs'),
    '#description' => $total_subscription_shorten_url,
    '#disabled' => !module_exists('shorten'),
  );

  return system_settings_form($form);
}

/**
 * Callback function for Admin settings for Mails.
 */
function total_subscription_admin_form() {
  $form = array();
  $form['total_subscription_send_start_template'] = array(
    '#type' => 'textarea',
    '#default_value'    => variable_get('total_subscription_send_start_template') ? variable_get('total_subscription_send_start_template') : '',
    '#description'      => t('Subscribe link will be added to the end automatically.'),
    '#title'            => t('Subscribe e-mail template'),
  );
  $form['total_unsubscription_send_start_template'] = array(
    '#type'             => 'textarea',
    '#default_value'    => variable_get('total_unsubscription_send_start_template') ? variable_get('total_unsubscription_send_start_template') : '',
    '#description'      => t('Unsubscribe link will be added to the end automatically.'),
    '#title'            => t('Unsubscribe e-mail template'),
  );
  $form['body_start_template'] = array(
    '#type'             => 'fieldset',
    '#title'            => t('Content e-mail template'),
    '#description'      => t('Fill this template to send e-mails to your subscribers.'),
  );
  $form['body_start_template']['total_subscription_email_template'] = array(
    '#type'             => 'textarea',
    '#default_value'    => variable_get('total_subscription_email_template') ? variable_get('total_subscription_email_template') : '',
    '#description'      => t('Link to unsubscribe form will be added to the end automatically.'),
    '#title'            => t('Content template'),
    '#rows'             => 20,
  );
  $form['body_start_template']['token_help'] = array(
    '#title' => t('Replacement patterns'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['body_start_template']['token_help']['help'] = array(
    '#theme' => 'token_tree',
    '#token_types' => array('node'),
  );
  $form['body_start_template']['total_subscription_html_templates'] = array(
    '#type' => 'checkbox',
    '#default_value' => variable_get('total_subscription_html_templates', 0),
    '#title' => t('Use HTML templates'),
    '#description' => t('You can send HTML e-mails if') .
    ' ' . l(t('Mime Mail'), 'http://drupal.org/project/mimemail') . ' ' . t('module installed.'),
    '#disabled' => !module_exists('mimemail'),
  );

  return system_settings_form($form);
}

/**
 * Implements callback for taxonomy search.
 */
function total_subscription_taxonomy_search() {
  $view = views_get_view('total_subscription');
  $view->set_display('block');
  $view->pre_execute();
  $view->execute();
  return $view->render();
}

/**
 * Implements callback for node search.
 */
function total_subscription_node_search() {
  $view = views_get_view('total_subscription');
  $view->set_display('block_1');
  // Change the amount of items to show.
  $view->pre_execute();
  $view->execute();
  return $view->render();
}
